@@ -1,6 +1,6 @@
 /*****************************************************************************
  * dr_47.c
- * Copyright (C) 2001-2010 VideoLAN
+ * Copyright (C) 2001-2011 VideoLAN
  * $Id: dr_47.c,v 1.1 2002/12/11 13:14:42 jobi Exp $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -22,11 +22,11 @@
  *
  *****************************************************************************/
 
-
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include <string.h>
 
 #if defined(HAVE_INTTYPES_H)
@@ -48,72 +48,65 @@
 dvbpsi_bouquet_name_dr_t * dvbpsi_DecodeBouquetNameDr(
                                         dvbpsi_descriptor_t * p_descriptor)
 {
-  dvbpsi_bouquet_name_dr_t * p_decoded;
+    dvbpsi_bouquet_name_dr_t * p_decoded;
 
-  /* Check the tag */
-  if(p_descriptor->i_tag != 0x47)
-  {
-    DVBPSI_ERROR_ARG("dr_47 decoder", "bad tag (0x%x)", p_descriptor->i_tag);
-    return NULL;
-  }
+    /* Check the tag */
+    if (!dvbpsi_CanDecodeAsDescriptor(p_descriptor, 0x47))
+        return NULL;
 
-  /* Don't decode twice */
-  if(p_descriptor->p_decoded)
-    return p_descriptor->p_decoded;
+    /* Don't decode twice */
+    if (dvbpsi_IsDescriptorDecoded(p_descriptor))
+        return p_descriptor->p_decoded;
 
-  /* Allocate memory */
-  p_decoded =
-        (dvbpsi_bouquet_name_dr_t*)malloc(sizeof(dvbpsi_bouquet_name_dr_t));
-  if(!p_decoded)
-  {
-    DVBPSI_ERROR("dr_47 decoder", "out of memory");
-    return NULL;
-  }
+    /* Allocate memory */
+    p_decoded = (dvbpsi_bouquet_name_dr_t*)malloc(sizeof(dvbpsi_bouquet_name_dr_t));
+    if (!p_decoded)
+        return NULL;
 
-  /* Decode data */
-  p_decoded->i_name_length = p_descriptor->i_length;
-  if(p_decoded->i_name_length)
-    memcpy(p_decoded->i_char,
-           p_descriptor->p_data,
-           p_decoded->i_name_length);
+    /* Decode data */
+    p_decoded->i_name_length = p_descriptor->i_length;
+    if (p_decoded->i_name_length > 255)
+        p_decoded->i_name_length = 255;
 
-  p_descriptor->p_decoded = (void*)p_decoded;
+    if (p_decoded->i_name_length)
+        memcpy(p_decoded->i_char,
+               p_descriptor->p_data,
+               p_decoded->i_name_length);
 
-  return p_decoded;
+    p_descriptor->p_decoded = (void*)p_decoded;
+
+    return p_decoded;
 }
 
 
 /*****************************************************************************
  * dvbpsi_GenBouquetNameDr
  *****************************************************************************/
-dvbpsi_descriptor_t * dvbpsi_GenBouquetNameDr(
-                                        dvbpsi_bouquet_name_dr_t * p_decoded,
-                                        int b_duplicate)
+dvbpsi_descriptor_t * dvbpsi_GenBouquetNameDr(dvbpsi_bouquet_name_dr_t *p_decoded,
+                                        bool b_duplicate)
 {
-  /* Create the descriptor */
-  dvbpsi_descriptor_t * p_descriptor =
-        dvbpsi_NewDescriptor(0x47, p_decoded->i_name_length, NULL);
+    if (p_decoded->i_name_length > 255)
+        p_decoded->i_name_length = 255;
+
+    /* Create the descriptor */
+    dvbpsi_descriptor_t * p_descriptor =
+            dvbpsi_NewDescriptor(0x47, p_decoded->i_name_length, NULL);
+    if (!p_descriptor)
+        return NULL;
 
-  if(p_descriptor)
-  {
     /* Encode data */
     if(p_decoded->i_name_length)
-      memcpy(p_descriptor->p_data,
-             p_decoded->i_char,
-             p_decoded->i_name_length);
+        memcpy(p_descriptor->p_data,
+               p_decoded->i_char,
+               p_decoded->i_name_length);
 
-    if(b_duplicate)
+    if (b_duplicate)
     {
-      /* Duplicate decoded data */
-      dvbpsi_bouquet_name_dr_t * p_dup_decoded =
-        (dvbpsi_bouquet_name_dr_t*)malloc(sizeof(dvbpsi_bouquet_name_dr_t));
-      if(p_dup_decoded)
-        memcpy(p_dup_decoded, p_decoded, sizeof(dvbpsi_bouquet_name_dr_t));
-
-      p_descriptor->p_decoded = (void*)p_dup_decoded;
+        /* Duplicate decoded data */
+        p_descriptor->p_decoded =
+                dvbpsi_DuplicateDecodedDescriptor(p_decoded,
+                                                  sizeof(dvbpsi_bouquet_name_dr_t));
     }
-  }
 
-  return p_descriptor;
+    return p_descriptor;
 }
-
